==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__24GtkErrorImage.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$GtkErrorImage

// class file dependencies
// @dep_class 6ff67b57c5b7cc98 gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage
// @dep_class a583b2049538a9e0 java_awt_Image
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Image

#include "java/awt/Image.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Image$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$_init$f631f69d01853bae(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getHeight$65fd8f44593d1096(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getProperty$4bfca031d28f9460(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_java_awt_Image$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getScaledInstance$dbc677c18e5edf90(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, jint, jint, jint);
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getSource$2a89dcb615ac4789(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
extern jint _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getWidth$f3efa3deabf3bc2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getHeight$65fd8f44593d1096;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getProperty$4bfca031d28f9460;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getScaledInstance$dbc677c18e5edf90;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getSource$2a89dcb615ac4789;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getWidth$f3efa3deabf3bc2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
	jint	(*getHeight$65fd8f44593d1096)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*getProperty$4bfca031d28f9460)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	struct _jc_java_awt_Image$object	*(*getScaledInstance$dbc677c18e5edf90)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, jint, jint, jint);
	struct _jc_object	*(*getSource$2a89dcb615ac4789)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *);
	jint	(*getWidth$f3efa3deabf3bc2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Image$vmethods	java_awt_Image;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
    _jc_java_awt_Image$sub_refs	java_awt_Image;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Image$sub_nonrefs	java_awt_Image;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__24GtkErrorImage.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$GtkErrorImage

// class file dependencies
// @dep_class 6ff67b57c5b7cc98 gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage
// @dep_class a583b2049538a9e0 java_awt_Image
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Image

#include "java/awt/Image.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Image$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$_init$f631f69d01853bae(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getHeight$65fd8f44593d1096(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getProperty$4bfca031d28f9460(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Image$object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getScaledInstance$dbc677c18e5edf90(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getSource$2a89dcb615ac4789(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method$getWidth$f3efa3deabf3bc2d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getHeight$65fd8f44593d1096;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getProperty$4bfca031d28f9460;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getScaledInstance$dbc677c18e5edf90;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getSource$2a89dcb615ac4789;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$method_info$getWidth$f3efa3deabf3bc2d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods {
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
	jint	(*getHeight$65fd8f44593d1096)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getProperty$4bfca031d28f9460)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Image$object	*(*getScaledInstance$dbc677c18e5edf90)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, jint, jint, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSource$2a89dcb615ac4789)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *) _JC_JCNI_ATTR;
	jint	(*getWidth$f3efa3deabf3bc2d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Image$vmethods	java_awt_Image;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
    _jc_java_awt_Image$sub_refs	java_awt_Image;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Image$sub_nonrefs	java_awt_Image;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__24GtkErrorImage_H_ */
